

/* just to force all refs */

extern int F77_aloc();
extern int abort_();
extern int f_back();
extern int c_abs();
extern int c_cos();
extern int c_div();
extern int c_exp();
extern int c_log();
extern int c_sin();
extern int c_sqrt();
extern int f__cabs();
extern int f_clos();
extern int flush_();
extern int d_abs();
extern int d_acos();
extern int d_asin();
extern int d_atan();
extern int d_atn2();
extern int d_cnjg();
extern int d_cos();
extern int d_cosh();
extern int d_dim();
extern int d_exp();
extern int d_imag();
extern int d_int();
extern int d_lg10();
extern int d_log();
extern int d_mod();
extern int d_nint();
extern int d_prod();
extern int d_sign();
extern int d_sin();
extern int d_sinh();
extern int d_sqrt();
extern int d_tan();
extern int d_tanh();
extern int derf_();
extern int derfc_(); 
extern int y_rsk();
extern int y_getc();
extern int y_putc();
extern int y_rev();
extern int y_err();
extern int y_newrec();
extern int c_dfe();
extern int s_rdfe();
extern int s_wdfe();
extern int e_rdfe();
extern int e_wdfe();
extern int do_lio();
extern int c_due();
extern int s_rdue();
extern int s_wdue();
extern int e_rdue();
extern int e_wdue();
extern int ef1asc_();
extern int ef1cmc_();
extern int f_end();
extern int t_runc();
extern int erf_();
/* extern int erfc_(); */
extern int f__canseek();
extern int f__fatal();
extern int f__nowreading();
extern int f__nowwriting();
extern int err__fl();
extern int exit_();
extern int ap_end();
extern int op_gen();
extern int gt_num();
extern int f_s();
extern int ne_d();
extern int e_d();
extern int i_tem();
extern int f_list();
extern int pars_f();
extern int type_f();
extern int do_fio();
extern int en_fio();
extern int fmt_bg();
extern int f__icvt();
extern int ftell_();
extern int fseek_();
extern int getarg_();
extern int getenv_();
extern int h_abs();
extern int h_dim();
extern int h_dnnt();
extern int h_indx();
extern int h_len();
extern int h_mod();
extern int h_nint();
extern int h_sign();
extern int hl_ge();
extern int hl_gt();
extern int hl_le();
extern int hl_lt();
extern int i_abs();
extern int i_dim();
extern int i_dnnt();
extern int i_indx();
extern int i_len();
extern int i_mod();
extern int i_nint();
extern int i_sign();
extern int iargc_();
extern int z_getc();
extern int z_putc();
extern int z_rnew();
extern int c_si();
extern int iw_rev();
extern int s_rsfi();
extern int z_wnew();
extern int s_wsfi();
extern int e_rsfi();
extern int e_wsfi();
extern int c_liw();
extern int s_wsni();
extern int s_wsli();
extern int e_wsli();
extern int f_inqu();
extern int l_ge();
extern int l_gt();
extern int l_le();
extern int l_lt();
extern int lbit_bits();
extern int lbit_cshift();
extern int lbit_shift();
extern int t_getc();
extern int e_rsle();
extern int l_R();
extern int l_C();
extern int l_L();
extern int l_CHAR();
extern int c_le();
extern int l_read();
extern int s_rsle();
extern int t_putc();
extern int l_write();
extern int f__isdev();
extern int f_open();
extern int fk_open();
extern int pow_ci();
extern int pow_dd();
extern int pow_di();
extern int pow_hh();
extern int pow_ii();
extern int pow_ri();
extern int pow_zi();
extern int pow_zz();
extern int r_abs();
extern int r_acos();
extern int r_asin();
extern int r_atan();
extern int r_atn2();
extern int r_cnjg();
extern int r_cos();
extern int r_cosh();
extern int r_dim();
extern int r_exp();
extern int r_imag();
extern int r_int();
extern int r_lg10();
extern int r_log();
extern int r_mod();
extern int r_nint();
extern int r_sign();
extern int r_sin();
extern int r_sinh();
extern int r_sqrt();
extern int r_tan();
extern int r_tanh();
extern int rd_ed();
extern int rd_ned();
extern int f_rew();
extern int xrd_SL();
extern int x_getc();
extern int x_endp();
extern int x_rev();
extern int s_rsfe();
extern int s_rsli();
extern int e_rsli();
extern int s_rsni();
extern int mk_hashtab();
extern int x_rsne();
extern int s_rsne();
extern int s_cat();
extern int s_cmp();
extern int s_copy();
extern int s_paus();
extern int s_rnge();
extern int s_stop();
extern int e_rsfe();
extern int c_sfe();
extern int e_wsfe();
extern int signal_();
extern int c_sue();
extern int s_rsue();
extern int s_wsue();
extern int e_wsue();
extern int e_rsue();
extern int system_();
extern int do_us();
extern int do_ud();
extern int do_uio();
extern int g_char();
extern int b_char();
extern int wrt_E();
extern int wrt_F();
extern int wrt_L();
extern int w_ed();
extern int w_ned();
extern int x_putc();
extern int x_wSL();
extern int xw_end();
extern int xw_rev();
extern int s_wsfe();
extern int s_wsle();
extern int e_wsle();
extern int s_wsne();
extern int x_wsne();
extern int z_abs();
extern int z_cos();
extern int z_div();
extern int z_exp();
extern int z_log();
extern int z_sin();
extern int z_sqrt();
extern int f_exit();
extern int f_init();
extern int send_xarg();
extern int sig_die();

void  f2c_entries() 
{
  F77_aloc();
  abort_();
  f_back();
  c_abs();
  c_cos();
  c_div();
  c_exp();
  c_log();
  c_sin();
  c_sqrt();
  f__cabs();
  f_clos();
  f_exit();
  flush_();
  d_abs();
  d_acos();
  d_asin();
  d_atan();
  d_atn2();
  d_cnjg();
  d_cos();
  d_cosh();
  d_dim();
  d_exp();
  d_imag();
  d_int();
  d_lg10();
  d_log();
  d_mod();
  d_nint();
  d_prod();
  d_sign();
  d_sin();
  d_sinh();
  d_sqrt();
  d_tan();
  d_tanh();
  derf_();
  derfc_();
  y_rsk();
  y_getc();
  y_putc();
  y_rev();
  y_err();
  y_newrec();
  c_dfe();
  s_rdfe();
  s_wdfe();
  e_rdfe();
  e_wdfe();
  do_lio();
  c_due();
  s_rdue();
  s_wdue();
  e_rdue();
  e_wdue();
  ef1asc_();
  ef1cmc_();
  f_end();
  t_runc();
  erf_();
  /*  erfc_(); */
  f__canseek();
  f__fatal();
  f_init();
  f__nowreading();
  f__nowwriting();
  err__fl();
  exit_();
  ap_end();
  op_gen();
  gt_num();
  f_s();
  ne_d();
  e_d();
  i_tem();
  f_list();
  pars_f();
  type_f();
  do_fio();
  en_fio();
  fmt_bg();
  f__icvt();
  ftell_();
  fseek_();
  send_xarg();
  getarg_();
  getenv_();
  h_abs();
  h_dim();
  h_dnnt();
  h_indx();
  h_len();
  h_mod();
  h_nint();
  h_sign();
  hl_ge();
  hl_gt();
  hl_le();
  hl_lt();
  i_abs();
  i_dim();
  i_dnnt();
  i_indx();
  i_len();
  i_mod();
  i_nint();
  i_sign();
  iargc_();
  z_getc();
  z_putc();
  z_rnew();
  c_si();
  iw_rev();
  s_rsfi();
  z_wnew();
  s_wsfi();
  e_rsfi();
  e_wsfi();
  c_liw();
  s_wsni();
  s_wsli();
  e_wsli();
  f_inqu();
  l_ge();
  l_gt();
  l_le();
  l_lt();
  lbit_bits();
  lbit_cshift();
  lbit_shift();
  t_getc();
  e_rsle();
  l_R();
  l_C();
  l_L();
  l_CHAR();
  c_le();
  l_read();
  s_rsle();
  t_putc();
  l_write();
  f__isdev();
  f_open();
  fk_open();
  pow_ci();
  pow_dd();
  pow_di();
  pow_hh();
  pow_ii();
  pow_ri();
  pow_zi();
  pow_zz();
  r_abs();
  r_acos();
  r_asin();
  r_atan();
  r_atn2();
  r_cnjg();
  r_cos();
  r_cosh();
  r_dim();
  r_exp();
  r_imag();
  r_int();
  r_lg10();
  r_log();
  r_mod();
  r_nint();
  r_sign();
  r_sin();
  r_sinh();
  r_sqrt();
  r_tan();
  r_tanh();
  rd_ed();
  rd_ned();
  f_rew();
  xrd_SL();
  x_getc();
  x_endp();
  x_rev();
  s_rsfe();
  s_rsli();
  e_rsli();
  s_rsni();
  mk_hashtab();
  x_rsne();
  s_rsne();
  s_cat();
  s_cmp();
  s_copy();
  s_paus();
  s_rnge();
  s_stop();
  e_rsfe();
  c_sfe();
  e_wsfe();
  sig_die();
  signal_();
  c_sue();
  s_rsue();
  s_wsue();
  e_wsue();
  e_rsue();
  system_();
  do_us();
  do_ud();
  do_uio();
  g_char();
  b_char();
  wrt_E();
  wrt_F();
  wrt_L();
  w_ed();
  w_ned();
  x_putc();
  x_wSL();
  xw_end();
  xw_rev();
  s_wsfe();
  s_wsle();
  e_wsle();
  s_wsne();
  x_wsne();
  z_abs();
  z_cos();
  z_div();
  z_exp();
  z_log();
  z_sin();
  z_sqrt();
}
